@@ -43,8 +43,8 @@
 #include <antlr3intstream.h>
 #include <antlr3config.h>
 
-#include "runtime/errorext.h"
-#include "runtime/systemimpl.h"
+#include "errorext.h"
+#include "systemimpl.h"
 
 pthread_once_t parser_once_create_key = PTHREAD_ONCE_INIT;
 pthread_key_t modelicaParserKey;
@@ -392,7 +392,11 @@ static void* parseString(const char* data, const char* interactiveFilename, int
   return parseStream(input, langStd, runningTestsuite);
 }
 
-static void* parseFile(const char* fileName, const char* infoName, int flags, const char *encoding, int langStd, int runningTestsuite)
+#ifdef OMENCRYPTION
+#include "../../OMEncryption/Parser/parseEncryption.c"
+#endif
+
+static void* parseFile(const char* fileName, const char* infoName, int flags, const char *encoding, int langStd, int runningTestsuite, const char* libraryPath, void* lveInstance)
 {
   bool debug         = false; //check_debug_flag("parsedebug");
 
@@ -416,6 +420,17 @@ static void* parseFile(const char* fileName, const char* infoName, int flags, co
   if (len > 3 && 0==strcmp(fileName+len-4,".mof"))
     ModelicaParser_flags |= PARSE_FLAT;
 
+#ifdef OMENCRYPTION
+  if (len > 3 && 0==strcmp(fileName+len-4,".moc")) {
+    return parseEncryptedFile(fileName, langStd, runningTestsuite, libraryPath, lveInstance);
+  }
+#else
+  if (len > 3 && 0==strcmp(fileName+len-4,".moc")) {
+    c_add_message(NULL,-1, ErrorType_scripting, ErrorLevel_error, gettext("Cannot load the encrypted package. OpenModelica is not compiled with encryption support."), NULL, 0);
+    return NULL;
+  }
+#endif
+
   /*
    * Workaround: ANTLR3 does not like 0-length files on Windows!
    * So we pass an empty string instead :)
@@ -438,3 +453,19 @@ static void* parseFile(const char* fileName, const char* infoName, int flags, co
   }
   return parseStream(input, langStd, runningTestsuite);
 }
+
+int startLibraryVendorExecutable(const char* path, void** lveInstance)
+{
+  *lveInstance = mmc_mk_some(0);
+#ifdef OMENCRYPTION
+  return startLibraryVendorExecutableImpl(path, lveInstance);
+#endif
+  return 0;
+}
+
+void stopLibraryVendorExecutable(void** lveInstance)
+{
+#ifdef OMENCRYPTION
+  stopLibraryVendorExecutableImpl(lveInstance);
+#endif
+}
