@@ -42,8 +42,7 @@ class TextEditor : public BaseEditor
 public:
   TextEditor(QWidget *pParent);
   void setPlainText(const QString &text);
-private:
-  bool mForceSetPlainText;
+  virtual void popUpCompleter();
 private slots:
   virtual void showContextMenu(QPoint point);
 public slots:
