@@ -34,9 +34,11 @@
 #include "Simulation/SimulationOutputWidget.h"
 #include "MainWindow.h"
 #include "Modeling/LibraryTreeWidget.h"
+#include "Modeling/ItemDelegate.h"
 #include "Options/OptionsDialog.h"
 #include "SimulationOutputHandler.h"
 #include "Editors/CEditor.h"
+#include "Editors/TextEditor.h"
 #include "SimulationProcessThread.h"
 #include "SimulationDialog.h"
 #include "TransformationalDebugger/TransformationsWidget.h"
@@ -155,10 +157,12 @@ void SimulationOutputTree::copyMessages()
     foreach (QModelIndex modelIndex, modelIndexes) {
       SimulationMessage *pSimulationMessage = static_cast<SimulationMessage*>(modelIndex.internalPointer());
       if (pSimulationMessage) {
-        textToCopy.append(QString("%1 | %2 | %3")
-                          .arg(pSimulationMessage->mStream)
-                          .arg(StringHandler::getSimulationMessageTypeString(pSimulationMessage->mType))
-                          .arg(pSimulationMessage->mText));
+        /* Ticket:4778 Remove HTML formatting. */
+//        textToCopy.append(QString("%1 | %2 | %3")
+//                          .arg(pSimulationMessage->mStream)
+//                          .arg(StringHandler::getSimulationMessageTypeString(pSimulationMessage->mType))
+//                          .arg(pSimulationMessage->mText));
+        textToCopy.append(QString(pSimulationMessage->mText).remove("<p>").remove("</p>"));
       }
     }
     QApplication::clipboard()->setText(textToCopy.join("\n"));
@@ -233,65 +237,113 @@ SimulationOutputWidget::SimulationOutputWidget(SimulationOptions simulationOptio
   mpCompilationOutputTextBox->setFont(QFont(Helper::monospacedFontInfo.family()));
   mpGeneratedFilesTabWidget->addTab(mpCompilationOutputTextBox, tr("Compilation"));
   mpGeneratedFilesTabWidget->setTabEnabled(1, false);
+  mGeneratedFilesList << "%1.makefile";
+  // cpp-runtime generated files
+  if (simulationOptions.getTargetLanguage().compare("Cpp") == 0) {
+    mGeneratedFilesList << "%1.bat"
+                        << "OMCpp%1.cpp"
+                        << "OMCpp%1.h"
+                        << "OMCpp%1.exp"
+                        << "OMCpp%1.lib"
+                        << "OMCpp%1AlgLoopMain.cpp"
+                        << "OMCpp%1CalcHelperMain.cpp"
+                        << "OMCpp%1CalcHelperMain.obj"
+                        << "OMCpp%1CalcHelperMain.o"
+                        << "OMCpp%1FactoryExport.cpp"
+                        << "OMCpp%1Functions.cpp"
+                        << "OMCpp%1Functions.h"
+                        << "OMCpp%1Initialize.cpp"
+                        << "OMCpp%1Initialize.h"
+                        << "OMCpp%1Jacobian.cpp"
+                        << "OMCpp%1Jacobian.h"
+                        << "OMCpp%1Main.cpp"
+                        << "OMCpp%1Main.obj"
+                        << "OMCpp%1Mixed.cpp"
+                        << "OMCpp%1Mixed.h"
+                        << "OMCpp%1StateSelection.cpp"
+                        << "OMCpp%1StateSelection.h"
+                        << "OMCpp%1Types.h"
+                        << "OMCpp%1WriteOutput.cpp"
+                        << "OMCpp%1WriteOutput.h";
+
+    mGeneratedAlgLoopFilesList << QString("OMCpp%1Algloop*.h").arg(simulationOptions.getOutputFileName())
+                               << QString("OMCpp%1Algloop*.cpp").arg(simulationOptions.getOutputFileName());
+  } else {
+    // c-runtime generated files
+    mGeneratedFilesList << "%1.c"
+                        << "%1.o"
+                        << "%1_01exo.c"
+                        << "%1_01exo.o"
+                        << "%1_02nls.c"
+                        << "%1_02nls.o"
+                        << "%1_03lsy.c"
+                        << "%1_03lsy.o"
+                        << "%1_04set.c"
+                        << "%1_04set.o"
+                        << "%1_05evt.c"
+                        << "%1_05evt.o"
+                        << "%1_06inz.c"
+                        << "%1_06inz.o"
+                        << "%1_07dly.c"
+                        << "%1_07dly.o"
+                        << "%1_08bnd.c"
+                        << "%1_08bnd.o"
+                        << "%1_09alg.c"
+                        << "%1_09alg.o"
+                        << "%1_10asr.c"
+                        << "%1_10asr.o"
+                        << "%1_11mix.c"
+                        << "%1_11mix.o"
+                        << "%1_11mix.h"
+                        << "%1_12jac.c"
+                        << "%1_12jac.o"
+                        << "%1_12jac.h"
+                        << "%1_13opt.c"
+                        << "%1_13opt.o"
+                        << "%1_13opt.h"
+                        << "%1_14lnz.c"
+                        << "%1_14lnz.o"
+                        << "%1_15syn.c"
+                        << "%1_15syn.o"
+                        << "%1_16dae.c"
+                        << "%1_16dae.o"
+                        << "%1_16dae.h"
+                        << "%1_17inl.c"
+                        << "%1_17inl.o"
+                        << "%1_functions.c"
+                        << "%1_functions.o"
+                        << "%1_functions.h"
+                        << "%1_records.c"
+                        << "%1_records.o"
+                        << "%1_includes.h"
+                        << "%1_literals.h"
+                        << "%1_model.h";
+
+    mGeneratedAlgLoopFilesList.clear();
+  }
   if (mSimulationOptions.getShowGeneratedFiles()) {
     QString workingDirectory = mSimulationOptions.getWorkingDirectory();
     QString outputFile = mSimulationOptions.getOutputFileName();
-    /* className.c tab */
-    addGeneratedFileTab(QString(workingDirectory).append("/").append(outputFile).append(".c"));
-    /* className_01exo.c tab */
-    addGeneratedFileTab(QString(workingDirectory).append("/").append(outputFile).append("_01exo.c"));
-    /* className_02nls.c tab */
-    addGeneratedFileTab(QString(workingDirectory).append("/").append(outputFile).append("_02nls.c"));
-    /* className_03lsy.c tab */
-    addGeneratedFileTab(QString(workingDirectory).append("/").append(outputFile).append("_03lsy.c"));
-    /* className_04set.c tab */
-    addGeneratedFileTab(QString(workingDirectory).append("/").append(outputFile).append("_04set.c"));
-    /* className_05evt.c tab */
-    addGeneratedFileTab(QString(workingDirectory).append("/").append(outputFile).append("_05evt.c"));
-    /* className_06inz.c tab */
-    addGeneratedFileTab(QString(workingDirectory).append("/").append(outputFile).append("_06inz.c"));
-    /* className_07dly.c tab */
-    addGeneratedFileTab(QString(workingDirectory).append("/").append(outputFile).append("_07dly.c"));
-    /* className_08bnd.c tab */
-    addGeneratedFileTab(QString(workingDirectory).append("/").append(outputFile).append("_08bnd.c"));
-    /* className_09alg.c tab */
-    addGeneratedFileTab(QString(workingDirectory).append("/").append(outputFile).append("_09alg.c"));
-    /* className_10asr.c tab */
-    addGeneratedFileTab(QString(workingDirectory).append("/").append(outputFile).append("_10asr.c"));
-    /* className_11mix.c tab */
-    addGeneratedFileTab(QString(workingDirectory).append("/").append(outputFile).append("_11mix.c"));
-    /* className_11mix.h tab */
-    addGeneratedFileTab(QString(workingDirectory).append("/").append(outputFile).append("_11mix.h"));
-    /* className_12jac.c tab */
-    addGeneratedFileTab(QString(workingDirectory).append("/").append(outputFile).append("_12jac.c"));
-    /* className_12jac.h tab */
-    addGeneratedFileTab(QString(workingDirectory).append("/").append(outputFile).append("_12jac.h"));
-    /* className_13opt.c tab */
-    addGeneratedFileTab(QString(workingDirectory).append("/").append(outputFile).append("_13opt.c"));
-    /* className_14lnz.c tab */
-    addGeneratedFileTab(QString(workingDirectory).append("/").append(outputFile).append("_14lnz.c"));
-    /* className_functions.c tab */
-    addGeneratedFileTab(QString(workingDirectory).append("/").append(outputFile).append("_functions.c"));
-    /* className_records.c tab */
-    addGeneratedFileTab(QString(workingDirectory).append("/").append(outputFile).append("_records.c"));
-    /* className_11mix.h tab */
-    addGeneratedFileTab(QString(workingDirectory).append("/").append(outputFile).append("_11mix.h"));
-    /* className_12jac.h tab */
-    addGeneratedFileTab(QString(workingDirectory).append("/").append(outputFile).append("_12jac.h"));
-    /* className_13opt.h tab */
-    addGeneratedFileTab(QString(workingDirectory).append("/").append(outputFile).append("_13opt.h"));
-    /* className_functions.h tab */
-    addGeneratedFileTab(QString(workingDirectory).append("/").append(outputFile).append("_functions.h"));
-    /* className_includes.h tab */
-    addGeneratedFileTab(QString(workingDirectory).append("/").append(outputFile).append("_includes.h"));
-    /* className_literals.h tab */
-    addGeneratedFileTab(QString(workingDirectory).append("/").append(outputFile).append("_literals.h"));
-    /* className_model.h tab */
-    addGeneratedFileTab(QString(workingDirectory).append("/").append(outputFile).append("_model.h"));
-    /* className_info.json tab */
-    addGeneratedFileTab(QString(workingDirectory).append("/").append(outputFile).append("_info.json"));
+    foreach (QString fileName, mGeneratedFilesList) {
+      // filter *.o files and .makefile
+      if (!fileName.endsWith(".o") && fileName.compare(".makefile") != 0) {
+        addGeneratedFileTab(QString("%1/%2").arg(workingDirectory, QString(fileName).arg(outputFile)));
+      }
+    }
+    // Delete the Algloop*.cpp/h files generated by cpp runtime
+    if (mSimulationOptions.getTargetLanguage().compare("Cpp") == 0) {
+      QStringList filesList = QDir(workingDirectory).entryList(mGeneratedAlgLoopFilesList, QDir::Files | QDir::NoSymLinks |
+                                                               QDir::NoDotAndDotDot | QDir::Writable | QDir::CaseSensitive);
+      foreach (QString fileName, filesList) {
+        addGeneratedFileTab(QString("%1/%2").arg(workingDirectory, fileName));
+      }
+    }
+    if (simulationOptions.getTargetLanguage().compare("C") == 0) {
+      /* className_info.json tab */
+      addGeneratedFileTab(QString("%1/%2%3").arg(workingDirectory, outputFile).arg("_info.json"));
+    }
     /* className_init.xml tab */
-    addGeneratedFileTab(QString(workingDirectory).append("/").append(outputFile).append("_init.xml"));
+    addGeneratedFileTab(QString("%1/%2%3").arg(workingDirectory, outputFile).arg("_init.xml"));
   }
   // layout
   QGridLayout *pMainLayout = new QGridLayout;
@@ -325,6 +377,10 @@ SimulationOutputWidget::SimulationOutputWidget(SimulationOptions simulationOptio
 
 SimulationOutputWidget::~SimulationOutputWidget()
 {
+  /* Ticket:3788 comment:12 Delete the entire simulation folder. */
+  if (OptionsDialog::instance()->getSimulationPage()->getDeleteEntireSimulationDirectoryCheckBox()->isChecked()) {
+    Utilities::removeDirectoryRecursivly(mSimulationOptions.getWorkingDirectory());
+  }
   if (mpSimulationOutputHandler) {
     delete mpSimulationOutputHandler;
   }
@@ -395,6 +451,42 @@ void SimulationOutputWidget::writeSimulationMessage(SimulationMessage *pSimulati
   }
 }
 
+/*!
+ * \brief SimulationOutputWidget::embeddedServerInitialized
+ * Calls a function for creating an OpcUaClient object.
+ */
+void SimulationOutputWidget::embeddedServerInitialized()
+{
+  MainWindow::instance()->getSimulationDialog()->createOpcUaClient(mSimulationOptions);
+}
+
+/*!
+ * \brief SimulationOutputWidget::deleteIntermediateCompilationFiles
+ * Deletes the intermediate compilation files
+ */
+void SimulationOutputWidget::deleteIntermediateCompilationFiles()
+{
+  if (OptionsDialog::instance()->getSimulationPage()->getDeleteIntermediateCompilationFilesCheckBox()->isChecked()) {
+    QString workingDirectory = mSimulationOptions.getWorkingDirectory();
+    QString outputFile = mSimulationOptions.getOutputFileName();
+    foreach (QString fileName, mGeneratedFilesList) {
+      if (QFile::exists(QString("%1/%2").arg(workingDirectory, QString(fileName).arg(outputFile)))) {
+        QFile::remove(QString("%1/%2").arg(workingDirectory, QString(fileName).arg(outputFile)));
+      }
+    }
+    // Delete the Algloop*.cpp/h files generated by cpp runtime
+    if (mSimulationOptions.getTargetLanguage().compare("Cpp") == 0) {
+      QStringList filesList = QDir(workingDirectory).entryList(mGeneratedAlgLoopFilesList, QDir::Files | QDir::NoSymLinks |
+                                                               QDir::NoDotAndDotDot | QDir::Writable | QDir::CaseSensitive);
+      foreach (QString fileName, filesList) {
+        if (QFile::exists(QString("%1/%2").arg(workingDirectory, fileName))) {
+          QFile::remove(QString("%1/%2").arg(workingDirectory, fileName));
+        }
+      }
+    }
+  }
+}
+
 /*!
  * \brief SimulationOutputWidget::createSimulationProgressSocket
  * Slot activated when QTcpServer newConnection SIGNAL is raised.\n
@@ -495,6 +587,10 @@ void SimulationOutputWidget::compilationProcessFinished(int exitCode, QProcess::
     MainWindow::instance()->getSimulationDialog()->showAlgorithmicDebugger(mSimulationOptions);
   }
   mpArchivedSimulationItem->setStatus(Helper::finished);
+  // remove the generated files
+  if (mSimulationOptions.getBuildOnly()) {
+    deleteIntermediateCompilationFiles();
+  }
 }
 
 /*!
@@ -504,16 +600,17 @@ void SimulationOutputWidget::compilationProcessFinished(int exitCode, QProcess::
  */
 void SimulationOutputWidget::simulationProcessStarted()
 {
-  mpProgressLabel->setText(tr("Running simulation of <b>%1</b>. Please wait for a while.").arg(mSimulationOptions.getClassName()));
+  if (mSimulationOptions.isInteractiveSimulation()) {
+    mpProgressLabel->setText(tr("Running interactive simulation of <b>%1</b>.").arg(mSimulationOptions.getClassName()));
+  } else {
+    mpProgressLabel->setText(tr("Running simulation of <b>%1</b>. Please wait for a while.").arg(mSimulationOptions.getClassName()));
+  }
   mpProgressBar->setRange(0, 100);
   mpProgressBar->setTextVisible(true);
   mpCancelButton->setText(Helper::cancelSimulation);
   mpCancelButton->setEnabled(true);
-  // save the last modified datetime of result file.
-  QFileInfo resultFileInfo(QString(mSimulationOptions.getWorkingDirectory()).append("/").append(mSimulationOptions.getResultFileName()));
-  if (resultFileInfo.exists()) {
-    mResultFileLastModifiedDateTime = resultFileInfo.lastModified();
-  }
+  // save the current datetime as last modified datetime for result file.
+  mResultFileLastModifiedDateTime = QDateTime::currentDateTime();
   mpArchivedSimulationItem->setStatus(Helper::running);
 }
 
@@ -527,15 +624,14 @@ void SimulationOutputWidget::simulationProcessStarted()
  */
 void SimulationOutputWidget::writeSimulationOutput(QString output, StringHandler::SimulationMessageType type, bool textFormat)
 {
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 0, 0))
-  QString escaped = QString(output).toHtmlEscaped();
-#else /* Qt4 */
-  QString escaped = Qt::escape(output);
-#endif
-
   mpGeneratedFilesTabWidget->setTabEnabled(0, true);
   if (isOutputStructured()) {
     if (textFormat) {
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 0, 0))
+      QString escaped = QString(output).toHtmlEscaped();
+#else /* Qt4 */
+      QString escaped = Qt::escape(output);
+#endif
       output = QString("<message stream=\"stdout\" type=\"%1\" text=\"%2\" />")
           .arg(StringHandler::getSimulationMessageTypeString(type))
           .arg(escaped);
@@ -587,6 +683,10 @@ void SimulationOutputWidget::simulationProcessFinished(int exitCode, QProcess::E
   mpCancelButton->setEnabled(false);
   MainWindow::instance()->getSimulationDialog()->simulationProcessFinished(mSimulationOptions, mResultFileLastModifiedDateTime);
   mpArchivedSimulationItem->setStatus(Helper::finished);
+  // remove the generated files
+  if (!mSimulationOptions.getBuildOnly()) {
+    deleteIntermediateCompilationFiles();
+  }
 }
 
 /*!
@@ -597,6 +697,7 @@ void SimulationOutputWidget::simulationProcessFinished(int exitCode, QProcess::E
 void SimulationOutputWidget::cancelCompilationOrSimulation()
 {
   if (mpSimulationProcessThread->isCompilationProcessRunning()) {
+    mpSimulationProcessThread->setCompilationProcessKilled(true);
     mpSimulationProcessThread->getCompilationProcess()->kill();
     mpProgressLabel->setText(tr("Compilation of <b>%1</b> is cancelled.").arg(mSimulationOptions.getClassName()));
     mpProgressBar->setRange(0, 1);
@@ -604,6 +705,7 @@ void SimulationOutputWidget::cancelCompilationOrSimulation()
     mpCancelButton->setEnabled(false);
     mpArchivedSimulationItem->setStatus(Helper::finished);
   } else if (mpSimulationProcessThread->isSimulationProcessRunning()) {
+    mpSimulationProcessThread->setSimulationProcessKilled(true);
     mpSimulationProcessThread->getSimulationProcess()->kill();
     mpProgressLabel->setText(tr("Simulation of <b>%1</b> is cancelled.").arg(mSimulationOptions.getClassName()));
     mpProgressBar->setValue(mpProgressBar->maximum());
@@ -653,3 +755,17 @@ void SimulationOutputWidget::openTransformationBrowser(QUrl url)
                           .arg(tr("Url is <b>%1</b>").arg(url.toString())), Helper::ok);
   }
 }
+
+/*!
+ * \brief SimulationOutputWidget::keyPressEvent
+ * Closes the widget when Esc key is pressed.
+ * \param event
+ */
+void SimulationOutputWidget::keyPressEvent(QKeyEvent *event)
+{
+  if (event->key() == Qt::Key_Escape) {
+    close();
+    return;
+  }
+  QWidget::keyPressEvent(event);
+}
