@@ -95,7 +95,9 @@ void SimulationProcessThread::compileModel()
 #else
   const char* omPlatform = "mingw32";
 #endif
-  args << simulationOptions.getOutputFileName() << pSimulationPage->getTargetCompilerComboBox()->currentText() << omPlatform << "parallel" << numProcs << "0";
+  args << simulationOptions.getOutputFileName()
+       << pSimulationPage->getTargetCompilerComboBox()->itemData(pSimulationPage->getTargetCompilerComboBox()->currentIndex()).toString()
+       << omPlatform << "parallel" << numProcs << "0";
   QString compilationProcessPath = QString(Helper::OpenModelicaHome) + "/share/omc/scripts/Compile.bat";
   emit sendCompilationOutput(QString("%1 %2\n").arg(compilationProcessPath).arg(args.join(" ")), Qt::blue);
   mpCompilationProcess->start(compilationProcessPath, args);
@@ -118,7 +120,11 @@ void SimulationProcessThread::runSimulationExecutable()
 {
   mpSimulationProcess = new QProcess;
   SimulationOptions simulationOptions = mpSimulationOutputWidget->getSimulationOptions();
-  mpSimulationProcess->setWorkingDirectory(simulationOptions.getWorkingDirectory());
+  /* Ticket:4583
+   * Use the OMEdit working directory so users can put their input files there.
+   */
+//  mpSimulationProcess->setWorkingDirectory(simulationOptions.getWorkingDirectory());
+  mpSimulationProcess->setWorkingDirectory(OptionsDialog::instance()->getGeneralSettingsPage()->getWorkingDirectory());
   qRegisterMetaType<StringHandler::SimulationMessageType>("StringHandler::SimulationMessageType");
   connect(mpSimulationProcess, SIGNAL(started()), SLOT(simulationProcessStarted()), Qt::DirectConnection);
   connect(mpSimulationProcess, SIGNAL(readyReadStandardOutput()), SLOT(readSimulationStandardOutput()), Qt::DirectConnection);
@@ -241,7 +247,14 @@ void SimulationProcessThread::simulationProcessStarted()
  */
 void SimulationProcessThread::readSimulationStandardOutput()
 {
-  emit sendSimulationOutput(QString(mpSimulationProcess->readAllStandardOutput()), StringHandler::Unknown, true);
+  /* The remote embedded server does not currently disconnect connected clients when a simulation finishes.
+   * This check hides the mazy network message of an open connection at shutdown.
+   */
+  QRegExp rx("info/network");
+  QString stdOutput = mpSimulationProcess->readAllStandardOutput();
+  if (!stdOutput.contains(rx)) {
+    emit sendSimulationOutput(stdOutput, StringHandler::Unknown, true);
+  }
 }
 
 /*!
