@@ -1,7 +1,7 @@
 /*
  * This file is part of OpenModelica.
  *
- * Copyright (c) 1998-2014, Open Source Modelica Consortium (OSMC),
+ * Copyright (c) 1998-CurrentYear, Open Source Modelica Consortium (OSMC),
  * c/o Linköpings universitet, Department of Computer and Information Science,
  * SE-58183 Linköping, Sweden.
  *
@@ -29,10 +29,7 @@
  *
  */
 /*
- *
  * @author Adeel Asghar <adeel.asghar@liu.se>
- *
- *
  */
 
 #include "Helper.h"
@@ -48,14 +45,15 @@ QString Helper::OpenModelicaVersion = "";
 QString Helper::OpenModelicaHome = "";
 QString Helper::OpenModelicaLibrary = "";
 QString Helper::OMCServerName = "OMEdit";
-QString Helper::omFileTypes = "Modelica Files (*.mo)";
+QString Helper::omFileTypes = "All Modelica Files (*.mo *.mol);;Modelica Files (*.mo);;Encrypted Modelica Libraries (*.mol)";
+QString Helper::omEncryptedFileTypes = "Encrypted Modelica Libraries (*.mol)";
 QString Helper::omnotebookFileTypes = "OMNotebook Files (*.onb *.onbz *.nb)";
 QString Helper::ngspiceNetlistFileTypes = "ngspice Netlist Files (*.cir *.sp *.spice)";
 QString Helper::imageFileTypes = "SVG (*.svg);;PNG image (*.png);;Windows BMP image (*.bmp);;TIFF (*.tiff)";
-QString Helper::bitmapFileTypes = "PNG image (*.png);Windows BMP image (*.bmp);JPEG (*.jpg *.jpeg)";
+QString Helper::bitmapFileTypes = "Image Files (*.png *.bmp *.jpg *.jpeg);;PNG image (*.png);;Windows BMP image (*.bmp);;JPEG (*.jpg *.jpeg)";
 QString Helper::fmuFileTypes = "FMU Files (*.fmu)";
 QString Helper::xmlFileTypes = "XML Files (*.xml)";
-QString Helper::infoXmlFileTypes = "OM Info Files (*_info.xml *_info.json)";
+QString Helper::infoXmlFileTypes = "OM Info Files (*_info.json)";
 QString Helper::matFileTypes = "MAT Files (*.mat)";
 QString Helper::omResultFileTypes = "OpenModelica Result Files (*.mat *.plt *.csv)";
 #ifdef WIN32
@@ -65,12 +63,15 @@ QString Helper::exeFileTypes = "Executable files (*)";
 #endif
 QString Helper::txtFileTypes = "TXT Files (*.txt)";
 QString Helper::figaroFileTypes = "Figaro Files (*.fi)";
+QString Helper::visualizationFileTypes = "Visualization Files (*.mat *.csv *.fmu);;Visualization MAT(*.mat);;Visualization CSV(*.csv);;Visualization FMU(*.fmu)";
+QString Helper::omsFileTypes = "Composite Model Files (*.ssp)";
+QString Helper::subModelFileTypes = "SubModel Files (*.fmu *.mat *.csv);;SubModel FMU (*.fmu);;SubModel MAT (*.mat);;SubModel CSV (*.csv)";
 int Helper::treeIndentation = 13;
 QSize Helper::iconSize = QSize(20, 20);
-QSize Helper::buttonIconSize = QSize(16, 16);
 int Helper::tabWidth = 20;
 QString Helper::modelicaComponentFormat = "image/modelica-component";
 QString Helper::modelicaFileFormat = "text/uri-list";
+QString Helper::busConnectorFormat = "bus/connector";
 qreal Helper::shapesStrokeWidth = 2.0;
 int Helper::headingFontSize = 18;
 QString Helper::ModelicaSimulationOutputFormats = "mat,plt,csv";
@@ -89,10 +90,15 @@ QString Helper::subWindow = "SubWindow";
 QString Helper::structuredOutput = "Structured";
 QString Helper::textOutput = "Text";
 QString Helper::utf8 = "UTF-8";
+const char * const Helper::fmuPlatformNamePropertyId = "fmu-platform-name";
 QFontInfo Helper::systemFontInfo = QFontInfo(QFont());
 QFontInfo Helper::monospacedFontInfo = QFontInfo(QFont());
+#ifdef Q_OS_MAC
+QString Helper::toolsOptionsPath = "OMEdit->Preferences";
+#else
 QString Helper::toolsOptionsPath = "Tools->Options";
-QString Helper::toolsOptionsPathMAC = "OMEdit->Preferences";
+#endif
+QString Helper::speedOptions = "10,5,2,1,0.5,0.2,0.1";
 /* Meta Modelica Types */
 QString Helper::MODELICA_METATYPE = QString("modelica_metatype");
 QString Helper::MODELICA_STRING = QString("modelica_string");
@@ -111,6 +117,10 @@ QString Helper::STRING = QString("String");
 QString Helper::BOOLEAN = QString("Boolean");
 QString Helper::INTEGER = QString("Integer");
 QString Helper::REAL = QString("Real");
+/* OMSimulator system types */
+QString Helper::systemTLM = QString("TLM - Transmission Line Modeling System");
+QString Helper::systemWC = QString("Weakly Coupled - Connected Co-Simulation FMUs System");
+QString Helper::systemSC = QString("Strongly Coupled - Connected Model-Exchange FMUs System");
 /* Global translated variables */
 QString Helper::newModelicaClass;
 QString Helper::createNewModelicaClass;
@@ -119,10 +129,13 @@ QString Helper::openConvertModelicaFiles;
 QString Helper::libraries;
 QString Helper::clearRecentFiles;
 QString Helper::encoding;
+QString Helper::fileLabel;
 QString Helper::file;
+QString Helper::folder;
 QString Helper::browse;
 QString Helper::ok;
 QString Helper::cancel;
+QString Helper::reset;
 QString Helper::close;
 QString Helper::error;
 QString Helper::chooseFile;
@@ -142,12 +155,15 @@ QString Helper::chooseDirectory;
 QString Helper::general;
 QString Helper::output;
 QString Helper::parameters;
+QString Helper::inputs;
 QString Helper::name;
 QString Helper::comment;
 QString Helper::path;
 QString Helper::type;
 QString Helper::information;
 QString Helper::rename;
+QString Helper::renameTip;
+QString Helper::OMSRenameTip;
 QString Helper::checkModel;
 QString Helper::checkModelTip;
 QString Helper::checkAllModels;
@@ -156,6 +172,8 @@ QString Helper::instantiateModel;
 QString Helper::instantiateModelTip;
 QString Helper::exportFMU;
 QString Helper::exportFMUTip;
+QString Helper::exportEncryptedPackage;
+QString Helper::exportEncryptedPackageTip;
 QString Helper::importFMU;
 QString Helper::importFMUTip;
 QString Helper::exportXML;
@@ -175,6 +193,9 @@ QString Helper::OpenModelicaCompilerCLI;
 QString Helper::deleteStr;
 QString Helper::copy;
 QString Helper::paste;
+QString Helper::resetZoom;
+QString Helper::zoomIn;
+QString Helper::zoomOut;
 QString Helper::loading;
 QString Helper::question;
 QString Helper::search;
@@ -182,18 +203,24 @@ QString Helper::unloadClass;
 QString Helper::duplicate;
 QString Helper::duplicateTip;
 QString Helper::unloadClassTip;
-QString Helper::unloadTLMOrTextTip;
+QString Helper::unloadCompositeModelOrTextTip;
+QString Helper::unloadOMSModelTip;
 QString Helper::refresh;
 QString Helper::simulate;
 QString Helper::simulateTip;
+QString Helper::callFunction;
+QString Helper::callFunctionTip;
 QString Helper::reSimulate;
 QString Helper::reSimulateTip;
 QString Helper::reSimulateSetup;
 QString Helper::reSimulateSetupTip;
+QString Helper::exportVariables;
 QString Helper::simulateWithTransformationalDebugger;
 QString Helper::simulateWithTransformationalDebuggerTip;
 QString Helper::simulateWithAlgorithmicDebugger;
 QString Helper::simulateWithAlgorithmicDebuggerTip;
+QString Helper::simulateWithAnimation;
+QString Helper::simulateWithAnimationTip;
 QString Helper::simulationSetup;
 QString Helper::simulationSetupTip;
 QString Helper::simulation;
@@ -221,7 +248,7 @@ QString Helper::arrowSize;
 QString Helper::size;
 QString Helper::lineStyle;
 QString Helper::color;
-QString Helper::fontAndColors;
+QString Helper::Colors;
 QString Helper::fontFamily;
 QString Helper::fontSize;
 QString Helper::pickColor;
@@ -246,15 +273,25 @@ QString Helper::iconView;
 QString Helper::diagramView;
 QString Helper::textView;
 QString Helper::documentationView;
-QString Helper::searchClasses;
+QString Helper::filterClasses;
 QString Helper::findReplaceModelicaText;
 QString Helper::left;
 QString Helper::center;
 QString Helper::right;
 QString Helper::createConnection;
+QString Helper::connectionAttributes;
+QString Helper::createTransition;
+QString Helper::editTransition;
 QString Helper::findVariables;
+QString Helper::filterVariables;
 QString Helper::openClass;
 QString Helper::openClassTip;
+QString Helper::viewIcon;
+QString Helper::viewIconTip;
+QString Helper::viewDiagram;
+QString Helper::viewDiagramTip;
+QString Helper::viewText;
+QString Helper::viewTextTip;
 QString Helper::viewDocumentation;
 QString Helper::viewDocumentationTip;
 QString Helper::dontShowThisMessageAgain;
@@ -275,6 +312,17 @@ QString Helper::executionFraction;
 QString Helper::debuggingFileNotSaveInfo;
 QString Helper::algorithmicDebugger;
 QString Helper::debugConfigurations;
+QString Helper::debugConfigurationsTip;
+QString Helper::createGitReposiory;
+QString Helper::createGitReposioryTip;
+QString Helper::logCurrentFile;
+QString Helper::logCurrentFileTip;
+QString Helper::stageCurrentFileForCommit;
+QString Helper::stageCurrentFileForCommitTip;
+QString Helper::unstageCurrentFileFromCommit;
+QString Helper::unstageCurrentFileFromCommitTip;
+QString Helper::commitFiles;
+QString Helper::commitFilesTip;
 QString Helper::resume;
 QString Helper::interrupt;
 QString Helper::exit;
@@ -282,6 +330,7 @@ QString Helper::stepOver;
 QString Helper::stepInto;
 QString Helper::stepReturn;
 QString Helper::attachToRunningProcess;
+QString Helper::attachToRunningProcessTip;
 QString Helper::crashReport;
 QString Helper::parsingFailedJson;
 QString Helper::expandAll;
@@ -292,15 +341,71 @@ QString Helper::simulationOutput;
 QString Helper::cancelSimulation;
 QString Helper::fetchInterfaceData;
 QString Helper::fetchInterfaceDataTip;
+QString Helper::alignInterfaces;
+QString Helper::alignInterfacesTip;
 QString Helper::tlmCoSimulationSetup;
 QString Helper::tlmCoSimulationSetupTip;
 QString Helper::tlmCoSimulation;
+QString Helper::animationChooseFile;
+QString Helper::animationChooseFileTip;
+QString Helper::animationInitialize;
+QString Helper::animationInitializeTip;
+QString Helper::animationPlay;
+QString Helper::animationPlayTip;
+QString Helper::animationPause;
+QString Helper::animationPauseTip;
+QString Helper::simulationParams;
+QString Helper::simulationParamsTip;
+QString Helper::newModel;
+QString Helper::addSystem;
+QString Helper::addSystemTip;
+QString Helper::addSubModel;
+QString Helper::addSubModelTip;
+QString Helper::addBus;
+QString Helper::addBusTip;
+QString Helper::editBus;
+QString Helper::addTLMBus;
+QString Helper::addTLMBusTip;
+QString Helper::editTLMBus;
+QString Helper::addConnector;
+QString Helper::addConnectorTip;
+QString Helper::addBusConnection;
+QString Helper::editBusConnection;
+QString Helper::addTLMConnection;
+QString Helper::editTLMConnection;
 QString Helper::running;
 QString Helper::finished;
 QString Helper::newVariable;
 QString Helper::library;
 QString Helper::moveUp;
 QString Helper::moveDown;
+QString Helper::fixErrorsManually;
+QString Helper::revertToLastCorrectVersion;
+QString Helper::OMCCommandLineOptions;
+QString Helper::OMCCommandLineOptionsTip;
+QString Helper::saveExperimentAnnotation;
+QString Helper::saveOpenModelicaSimulationFlagsAnnotation;
+QString Helper::item;
+QString Helper::bold;
+QString Helper::italic;
+QString Helper::underline;
+QString Helper::condition;
+QString Helper::immediate;
+QString Helper::synchronize;
+QString Helper::priority;
+QString Helper::secs;
+QString Helper::saveContentsInOneFile;
+QString Helper::OMSSimulateTip;
+QString Helper::dateTime;
+QString Helper::startTime;
+QString Helper::stopTime;
+QString Helper::status;
+QString Helper::speed;
+QString Helper::instantiateOMSModelTip;
+QString Helper::terminateInstantiation;
+QString Helper::terminateInstantiationTip;
+QString Helper::archivedSimulations;
+QString Helper::systemSimulationInformation;
 
 void Helper::initHelperVariables()
 {
@@ -312,10 +417,13 @@ void Helper::initHelperVariables()
   Helper::libraries = tr("Libraries");
   Helper::clearRecentFiles = tr("Clear Recent Files");
   Helper::encoding = tr("Encoding:");
-  Helper::file = tr("File:");
+  Helper::fileLabel = tr("File:");
+  Helper::file = tr("File");
+  Helper::folder = tr("Folder");
   Helper::browse = tr("Browse...");
   Helper::ok = tr("OK");
   Helper::cancel = tr("Cancel");
+  Helper::reset = tr("Reset");
   Helper::close = tr("Close");
   Helper::error = tr("Error");
   Helper::chooseFile = tr("Choose File");
@@ -336,12 +444,15 @@ void Helper::initHelperVariables()
   Helper::general = tr("General");
   Helper::output = tr("Output");
   Helper::parameters = tr("Parameters");
+  Helper::inputs = tr("Inputs");
   Helper::name = tr("Name:");
   Helper::comment = tr("Comment:");
   Helper::path = tr("Path:");
   Helper::type = tr("Type");
   Helper::information = tr("Information");
-  Helper::rename = tr("rename");
+  Helper::rename = tr("Rename");
+  Helper::renameTip = tr("Renames an item");
+  Helper::OMSRenameTip = tr("OMSimulator rename");
   Helper::checkModel = tr("Check Model");
   Helper::checkModelTip = tr("Check the Modelica class");
   Helper::checkAllModels = tr("Check All Models");
@@ -350,6 +461,8 @@ void Helper::initHelperVariables()
   Helper::instantiateModelTip = tr("Instantiate/Flatten the Modelica class");
   Helper::exportFMU = tr("Export FMU");
   Helper::exportFMUTip = tr("Exports the model as Functional Mockup Unit (FMU)");
+  Helper::exportEncryptedPackage = tr("Export Encrypted Package");
+  Helper::exportEncryptedPackageTip = tr("Exports the package as Encrytped package");
   Helper::importFMU = tr("Import FMU");
   Helper::importFMUTip = tr("Imports the model from Functional Mockup Interface (FMU)");
   Helper::exportXML = tr("Export XML");
@@ -369,6 +482,9 @@ void Helper::initHelperVariables()
   Helper::deleteStr = tr("Delete");
   Helper::copy = tr("Copy");
   Helper::paste = tr("Paste");
+  Helper::resetZoom = tr("Reset Zoom");
+  Helper::zoomIn = tr("Zoom In");
+  Helper::zoomOut = tr("Zoom Out");
   Helper::loading = tr("Loading");
   Helper::question = tr("Question");
   Helper::search = tr("Search");
@@ -376,18 +492,24 @@ void Helper::initHelperVariables()
   Helper::duplicateTip = tr("Duplicates the item");
   Helper::unloadClass = tr("Unload");
   Helper::unloadClassTip = tr("Unload the Modelica class");
-  Helper::unloadTLMOrTextTip = tr("Unload the TLM/Text file");
+  Helper::unloadCompositeModelOrTextTip = tr("Unloads the CompositeModel/Text file");
+  Helper::unloadOMSModelTip = tr("Unloads the model");
   Helper::refresh = tr("Refresh");
   Helper::simulate = tr("Simulate");
   Helper::simulateTip = tr("Simulates the Modelica class");
+  Helper::callFunction = tr("Call function");
+  Helper::callFunctionTip = tr("Calls the Modelica function");
   Helper::reSimulate = tr("Re-simulate");
   Helper::reSimulateTip = tr("Re-simulates the Modelica class");
   Helper::reSimulateSetup = tr("Re-simulate Setup");
   Helper::reSimulateSetupTip = tr("Setup re-simulation settings");
+  Helper::exportVariables = tr("Export Variables");
   Helper::simulateWithTransformationalDebugger = tr("Simulate with Transformational Debugger");
   Helper::simulateWithTransformationalDebuggerTip = tr("Simulates the Modelica class with Transformational Debugger");
   Helper::simulateWithAlgorithmicDebugger = tr("Simulate with Algorithmic Debugger");
   Helper::simulateWithAlgorithmicDebuggerTip = tr("Simulates the Modelica class with Algorithmic Debugger");
+  Helper::simulateWithAnimation = tr("Simulate with Animation");
+  Helper::simulateWithAnimationTip = tr("Simulates the Modelica class with Animation");
   Helper::simulationSetup = tr("Simulation Setup");
   Helper::simulationSetupTip = tr("Setup simulation settings");
   Helper::simulation = tr("Simulation");
@@ -415,7 +537,7 @@ void Helper::initHelperVariables()
   Helper::size = tr("Size:");
   Helper::lineStyle = tr("Line Style");
   Helper::color = tr("Color:");
-  Helper::fontAndColors = tr("Font and Colors");
+  Helper::Colors = tr("Colors");
   Helper::fontFamily = tr("Font Family:");
   Helper::fontSize = tr("Font Size:");
   Helper::pickColor = tr("Pick Color");
@@ -440,15 +562,25 @@ void Helper::initHelperVariables()
   Helper::diagramView = tr("Diagram View");
   Helper::textView = tr("Text View");
   Helper::documentationView = tr("Documentation View");
-  Helper::searchClasses = tr("Search Classes");
+  Helper::filterClasses = tr("Filter Classes");
   Helper::findReplaceModelicaText = tr("Find/Replace...");
   Helper::left = tr("Left");
   Helper::center = tr("Center");
   Helper::right = tr("Right");
   Helper::createConnection = tr("Create Connection");
+  Helper::connectionAttributes = tr("Connection Attributes");
+  Helper::createTransition = tr("Create Transition");
+  Helper::editTransition = tr("Edit Transition");
   Helper::findVariables = tr("Find Variables");
+  Helper::filterVariables = tr("Filter Variables");
   Helper::openClass = tr("Open Class");
   Helper::openClassTip = tr("Opens the class details");
+  Helper::viewIcon = tr("View Icon");
+  Helper::viewIconTip = tr("Opens the class icon");
+  Helper::viewDiagram = tr("View Diagram");
+  Helper::viewDiagramTip = tr("Opens the class diagram");
+  Helper::viewText = tr("View Text");
+  Helper::viewTextTip = tr("Opens the class text");
   Helper::viewDocumentation = tr("View Documentation");
   Helper::viewDocumentationTip = tr("Opens the class documentation");
   Helper::dontShowThisMessageAgain = tr("Don't show this message again");
@@ -469,6 +601,17 @@ void Helper::initHelperVariables()
   Helper::debuggingFileNotSaveInfo = tr("<b>Info: </b>Update the actual model in <b>Modeling</b> perspective and simulate again. This is only shown for debugging purpose. Your changes will not be saved.");
   Helper::algorithmicDebugger = tr("Algorithmic Debugger");
   Helper::debugConfigurations = tr("Debug Configurations");
+  Helper::debugConfigurationsTip = tr("Manage debug configurations");
+  Helper::createGitReposiory = tr("Create Repository");
+  Helper::createGitReposioryTip = tr("Create a Git repository");
+  Helper::logCurrentFile = tr("Log Current File");
+  Helper::logCurrentFileTip = tr("Logging current file");
+  Helper::stageCurrentFileForCommit = tr("Stage Current File");
+  Helper::stageCurrentFileForCommitTip = tr("Staging current file for next commit");
+  Helper::unstageCurrentFileFromCommit = tr("Unstage Current File");
+  Helper::unstageCurrentFileFromCommitTip = tr("Unstaging current file from next commit");
+  Helper::commitFiles = tr("Commit");
+  Helper::commitFilesTip = tr("Commiting modified files to the repository");
   Helper::resume = tr("Resume");
   Helper::interrupt = tr("Interrupt");
   Helper::exit = tr("Exit");
@@ -476,6 +619,7 @@ void Helper::initHelperVariables()
   Helper::stepInto = tr("Step Into");
   Helper::stepReturn = tr("Step Return");
   Helper::attachToRunningProcess = tr("Attach to Running Process");
+  Helper::attachToRunningProcessTip = tr("Attach the debugger to running process");
   Helper::crashReport = tr("Crash Report");
   Helper::parsingFailedJson = tr("Parsing of JSON file failed");
   Helper::expandAll = tr("Expand All");
@@ -485,16 +629,72 @@ void Helper::initHelperVariables()
   Helper::simulationOutput = tr("Simulation Output");
   Helper::cancelSimulation = tr("Cancel Simulation");
   Helper::fetchInterfaceData = tr("Fetch Interface Data");
-  Helper::fetchInterfaceDataTip = tr("Fetches the interface data for TLM co-simulation");
+  Helper::fetchInterfaceDataTip = tr("Fetches the interface data");
+  Helper::alignInterfaces = tr("Align Interfaces");
+  Helper::alignInterfacesTip = tr("Aligns the interfaces");
   Helper::tlmCoSimulationSetup = tr("TLM Co-Simulation Setup");
   Helper::tlmCoSimulationSetupTip = tr("Opens the TLM co-simulation setup");
   Helper::tlmCoSimulation = tr("TLM Co-Simulation");
+  Helper::animationChooseFile = tr("Animation File");
+  Helper::animationChooseFileTip = tr("Open an animation.");
+  Helper::animationInitialize = tr("Initialize");
+  Helper::animationInitializeTip = tr("Initialize the animation scene");
+  Helper::animationPlay = tr("Play");
+  Helper::animationPlayTip = tr("Play the animation");
+  Helper::animationPause = tr("Pause");
+  Helper::animationPauseTip = tr("Pause the animation");
+  Helper::simulationParams = tr("Simulation Parameters");
+  Helper::simulationParamsTip = tr("Shows the Simulation Parameters dialog");
+  Helper::newModel = tr("New OMSimulator Model");
+  Helper::addSystem = tr("Add System");
+  Helper::addSystemTip = tr("Adds the System i.e., FMI or TLM");
+  Helper::addSubModel = tr("Add SubModel");
+  Helper::addSubModelTip = tr("Adds the SubModel i.e., FMU or Table");
+  Helper::addBus = tr("Add Bus");
+  Helper::addBusTip = tr("Adds the bus");
+  Helper::editBus = tr("Edit Bus");
+  Helper::addTLMBus = tr("Add TLM Bus");
+  Helper::addTLMBusTip = tr("Adds the TLM bus");
+  Helper::editTLMBus = tr("Edit TLM Bus");
+  Helper::addConnector = tr("Add Connector");
+  Helper::addConnectorTip = tr("Adds the connector");
+  Helper::addBusConnection = tr("Add Bus Connection");
+  Helper::editBusConnection = tr("Edit Bus Connection");
+  Helper::addTLMConnection = tr("Add TLM Connection");
+  Helper::editTLMConnection = tr("Edit TLM Connection");
   Helper::running = tr("Running");
   Helper::finished = tr("Finished");
   Helper::newVariable = tr("<New Variable>");
   Helper::library = tr("Library");
   Helper::moveUp = tr("Move Up");
   Helper::moveDown = tr("Move Down");
+  Helper::fixErrorsManually = tr("Fix error(s) manually");
+  Helper::revertToLastCorrectVersion = tr("Revert to last correct version");
+  Helper::OMCCommandLineOptions = tr("OMC Command Line Options");
+  Helper::OMCCommandLineOptionsTip = tr("Space separated list of OMC command line options e.g., -d=initialization --cheapmatchingAlgorithm=3");
+  Helper::saveExperimentAnnotation = tr("Save experiment annotation inside model");
+  Helper::saveOpenModelicaSimulationFlagsAnnotation = tr("Save __OpenModelica_simulationFlags annotation inside model");
+  Helper::item = tr("item");
+  Helper::bold = tr("Bold");
+  Helper::italic = tr("Italic");
+  Helper::underline = tr("Underline");
+  Helper::condition = tr("Condition:");
+  Helper::immediate = tr("Immediate");
+  Helper::synchronize = tr("Synchronize");
+  Helper::priority = tr("Priority:");
+  Helper::secs = tr("secs");
+  Helper::saveContentsInOneFile = tr("Save contents in one file");
+  Helper::OMSSimulateTip = tr("Simulates the OMSimulator model");
+  Helper::dateTime = tr("DateTime");
+  Helper::startTime = tr("Start Time");
+  Helper::stopTime = tr("Stop Time");
+  Helper::status = tr("Status");
+  Helper::speed = tr("Speed:");
+  Helper::instantiateOMSModelTip = tr("Instantiates the OMSimulator model");
+  Helper::terminateInstantiation = tr("Terminate Instantiation");
+  Helper::terminateInstantiationTip = tr("Terminates the model instantiation");
+  Helper::archivedSimulations = tr("Archived Simulations");
+  Helper::systemSimulationInformation = tr("System Simulation Information");
 }
 
 QString GUIMessages::getMessage(int type)
@@ -504,7 +704,7 @@ QString GUIMessages::getMessage(int type)
     case CHECK_MESSAGES_BROWSER:
       return tr("Please check the Messages Browser for more error specific details.");
     case SAME_COMPONENT_NAME:
-      return tr("A Component with the same name already exists. Please choose another Name.");
+      return tr("A component with the name <b>%1</b> already exists. Please choose another name.");
     case SAME_COMPONENT_CONNECT:
       return tr("You cannot connect a component to itself.");
     case NO_MODELICA_CLASS_OPEN:
@@ -526,7 +726,7 @@ QString GUIMessages::getMessage(int type)
     case OPENMODELICAHOME_NOT_FOUND:
       return tr("Could not find environment variable OPENMODELICAHOME. Please make sure OpenModelica is installed properly.");
     case ERROR_OCCURRED:
-      return tr("Following error has occurred. \n\n%1");
+      return tr("Following error has occurred.<br />%1");
     case ERROR_IN_TEXT:
       return tr("Problems are found in %1 Text. <br />");
     case REVERT_PREVIOUS_OR_FIX_ERRORS_MANUALLY:
@@ -538,7 +738,9 @@ QString GUIMessages::getMessage(int type)
     case UNABLE_TO_OPEN_FILE:
       return tr("Unable to open file <b>%1</b>.");
     case UNABLE_TO_SAVE_FILE:
-      return tr("Unable to save the file <b>%1</b>.");
+      return tr("Unable to save the file <b>%1</b>. %2");
+    case UNABLE_TO_DELETE_FILE:
+      return tr("Unable to delete <b>%1</b>.");
     case FILE_NOT_FOUND:
       return tr("The file <b>%1</b> not found.");
     case ERROR_OPENING_FILE:
@@ -557,8 +759,6 @@ QString GUIMessages::getMessage(int type)
       return tr("You cannot insert <b>%1</b>, it is a <b>%2</b>. Only <b>connector</b> is allowed on the icon layer.");
     case PLOT_PARAMETRIC_DIFF_FILES:
       return tr("You cannot do a plot parametric between two different simulation result files. Make sure you select two variables from the same simulation result file.");
-    case FILE_FORMAT_NOT_SUPPORTED:
-      return tr("The file <b>%1</b> is not a valid Modelica file. The file format is not supported. You can only open <b>%2</b>.");
     case ENTER_VALID_NUMBER:
       return tr("Enter a valid number value for <b>%1</b>.");
     case ENTER_VALUE:
@@ -570,21 +770,27 @@ QString GUIMessages::getMessage(int type)
     case INNER_MODEL_NAME_CHANGED:
       return tr("A component with the name <b>%1</b> already exists. The name is changed from <b>%1</b> to <b>%2</b>.<br /><br />This is probably wrong because the component is declared as <b>inner</b>.");
     case FMU_GENERATED:
-      return tr("The FMU %1.fmu is generated at %2");
+      return tr("The FMU is generated at <b>%1</b>.");
+    case FMU_EMPTY_PLATFORMS:
+      return tr("A source-only FMU will be generated because an empty list of platforms is selected. If this is not intended, check settings in <b>%1->FMI->Platforms</b>.");
     case XML_GENERATED:
-      return tr("The XML is generated at %1/%2.xml");
+      return tr("The XML is generated at <b>%1</b>.");
     case FIGARO_GENERATED:
       return tr("The FIGARO is generated.");
+    case ENCRYPTED_PACKAGE_GENERATED:
+      return tr("The encrytped package is generated at <b>%1</b>.");
     case UNLOAD_CLASS_MSG:
       return tr("Are you sure you want to unload <b>%1</b>? Everything contained inside this class will also be unloaded.");
     case DELETE_CLASS_MSG:
       return tr("Are you sure you want to delete <b>%1</b>? Everything contained inside this class will also be deleted.");
-    case DELETE_TEXT_FILE_MSG:
+    case UNLOAD_TEXT_FILE_MSG:
       return tr("Are you sure you want to unload <b>%1</b>?");
+    case DELETE_TEXT_FILE_MSG:
+      return tr("Are you sure you want to delete <b>%1</b>?<br /><br />This will also delete from file system.");
     case WRONG_MODIFIER:
       return tr("The Modifier <b>%1</b> format is invalid. The correct format is <b>phi(start=1)</b>");
     case SET_INFO_XML_FLAG:
-      return tr("The operations were not generated. Check Generate Operations in <b>%1->Debugger->Transformational Debugger</b> OR you must set the +d=infoXmlOperations flag via <b>%2->Simulation->OMC Flags</b> and simulate again.");
+      return tr("The operations were not generated. Check Generate Operations in <b>%1->Debugger->Transformational Debugger</b> OR you must set the -d=infoXmlOperations flag via <b>%2->Simulation->OMC Command Line Options</b> and simulate again.");
     case DEBUG_CONFIGURATION_EXISTS_MSG:
       return tr("A debug configuration with name <b>%1</b> already exists. Error occurred while saving the debug configuration <b>%2<b>.");
     case DEBUG_CONFIGURATION_SIZE_EXCEED:
@@ -601,45 +807,32 @@ QString GUIMessages::getMessage(int type)
       return tr("The class <b>%1</b> is not a modelica class. Breakpoints are only allowed on modelica classes.");
     case TLMMANAGER_NOT_SET:
       return tr("TLM Manager executable path is not set. Set it via <b>%1->TLM</b>");
-    case METAMODEL_UNSAVED:
-      return tr("Metamodel <b>%1</b> has unsaved changes. Do you want to save?");
+    case COMPOSITEMODEL_UNSAVED:
+      return tr("CompositeModel <b>%1</b> has unsaved changes. Do you want to save?");
     case TLMCOSIMULATION_ALREADY_RUNNING:
       return tr("TLM co-simulation session is already running. Only one session is allowed.");
     case TERMINAL_COMMAND_NOT_SET:
       return tr("Terminal command is not set. You can define a new terminal command in <b>%1->General->Terminal Command</b>.");
+    case UNABLE_FIND_COMPONENT_IN_CONNECTION:
+      return tr("Unable to find component %1 while parsing connection %2.");
+    case UNABLE_FIND_COMPONENT_IN_TRANSITION:
+      return tr("Unable to find component %1 while parsing transition(%2).");
+    case UNABLE_FIND_COMPONENT_IN_INITIALSTATE:
+      return tr("Unable to find component %1 while parsing initialState(%2).");
+    case SELECT_SIMULATION_OPTION:
+      return tr("Select at least one of the following options, <br /><br />* %1<br />* %2<br />* %3")
+          .arg(Helper::saveExperimentAnnotation)
+          .arg(Helper::saveOpenModelicaSimulationFlagsAnnotation)
+          .arg(Helper::simulate);
+    case INVALID_TRANSITION_CONDITION:
+      return tr("Please enter a valid condition e.g., x >=0.");
+    case MULTIPLE_DECLARATIONS_COMPONENT:
+      return tr("Multiple declarations of component <b>%1</b> are found.");
+    case GDB_ERROR:
+      return tr("Following error has occurred <b>%1</b> GDB arguments are <b>\"%2\"</b>");
+    case INVALID_INSTANCE_NAME:
+      return tr("Name <b>%1</b> is not a valid identifier.<br />A name must start with a letter, and all characters must be letters or digits. It may not be a reserved word.");
     default:
       return "";
   }
 }
-
-QString& OpenModelica::tempDirectory()
-{
-  static int init = 0;
-  static QString tmpPath;
-  if (!init) {
-    init = 1;
-#ifdef WIN32
-    tmpPath = QDir::tempPath() + "/OpenModelica/OMEdit/";
-#else // UNIX environment
-    char *user = getenv("USER");
-    tmpPath = QDir::tempPath() + "/OpenModelica_" + QString(user ? user : "nobody") + "/OMEdit/";
-#endif
-    tmpPath.remove("\"");
-    if (!QDir().exists(tmpPath))
-      QDir().mkpath(tmpPath);
-  }
-  return tmpPath;
-}
-
-QSettings* OpenModelica::getApplicationSettings()
-{
-  static int init = 0;
-  static QSettings *pSettings;
-  if (!init) {
-    init = 1;
-    pSettings = new QSettings(QSettings::IniFormat, QSettings::UserScope, Helper::organization, Helper::application);
-    pSettings->setIniCodec(Helper::utf8.toStdString().data());
-  }
-  return pSettings;
-}
-
