@@ -1,7 +1,7 @@
 /*
  * This file is part of OpenModelica.
  *
- * Copyright (c) 1998-2014, Open Source Modelica Consortium (OSMC),
+ * Copyright (c) 1998-CurrentYear, Open Source Modelica Consortium (OSMC),
  * c/o Linköpings universitet, Department of Computer and Information Science,
  * SE-58183 Linköping, Sweden.
  *
@@ -57,7 +57,11 @@
 
 #include "OMEditApplication.h"
 #include "CrashReport/CrashReportDialog.h"
+#define GC_THREADS
+
+extern "C" {
 #include "meta/meta_modelica.h"
+}
 
 #include <QMessageBox>
 
@@ -141,9 +145,9 @@ void printOMEditUsage()
 
 int main(int argc, char *argv[])
 {
-  /* Do not use the signal handler OR exception filter if user is building a debug version. Perhaps the user wants to use gdb. */
   MMC_INIT();
-
+  MMC_TRY_TOP()
+  /* Do not use the signal handler OR exception filter if user is building a debug version. Perhaps the user wants to use gdb. */
 #ifdef QT_NO_DEBUG
 #ifdef WIN32
   SetUnhandledExceptionFilter(exceptionFilter);
@@ -166,6 +170,8 @@ int main(int argc, char *argv[])
     }
   }
   Q_INIT_RESOURCE(resource_omedit);
-  OMEditApplication a(argc, argv);
+  OMEditApplication a(argc, argv, threadData);
   return a.exec();
+
+  MMC_CATCH_TOP();
 }
