@@ -464,24 +464,14 @@ oms_status_enu_t oms::Model::initialize()
 
 oms_status_enu_t oms::Model::simulate_asynchronous(void (*cb)(const char* cref, double time, oms_status_enu_t status))
 {
-  clock.tic();
   if (!validState(oms_modelState_simulation))
-  {
-    clock.toc();
     return logError_ModelInWrongState(this);
-  }
 
   if (!system)
-  {
-    clock.toc();
     return logError("Model doesn't contain a system");
-  }
 
   std::thread([=]{system->stepUntil(stopTime, cb);}).detach();
-  emit(stopTime, true);
-  clock.toc();
-
-  return oms_status_ok;
+  return oms_status_pending;
 }
 
 oms_status_enu_t oms::Model::simulate()
@@ -584,7 +574,6 @@ oms_status_enu_t oms::Model::registerSignalsForResultFile()
   if (!resultFile)
     return oms_status_ok;
 
-  clock_id = resultFile->addSignal("$wallTime", "wall-clock time [s]", SignalType_REAL);
   if (system)
     if (oms_status_ok != system->registerSignalsForResultFile(*resultFile))
       return oms_status_error;
@@ -598,9 +587,6 @@ oms_status_enu_t oms::Model::emit(double time, bool force)
   if (!force && time < lastEmit + loggingInterval)
     return oms_status_ok;
 
-  SignalValue_t wallTime;
-  wallTime.realValue = clock.getElapsedWallTime();
-  resultFile->updateSignal(clock_id, wallTime);
   if (system)
     if (oms_status_ok != system->updateSignals(*resultFile))
       return oms_status_error;
